@@ -6,12 +6,12 @@
 ;; Homepage: https://github.com/magit/sisyphus
 ;; Keywords: git tools vc
 
-;; Package-Version: 0.3.0
-;; Package-Revision: v0.3.0-0-g0c94d3a09123
+;; Package-Version: 0.3.1
+;; Package-Revision: v0.3.1-0-g8fe6d76d3d31
 ;; Package-Requires: (
 ;;     (emacs   "30.1")
 ;;     (compat  "30.1")
-;;     (cond-let "0.1")
+;;     (cond-let "0.2")
 ;;     (elx      "2.3")
 ;;     (llama    "1.0")
 ;;     (magit    "4.4"))
@@ -45,6 +45,8 @@
 (require 'elx)
 (require 'magit-tag)
 
+(declare-function borg-worktree "ext:borg" (clone))
+
 ;;; Add Bindings
 
 ;;;###autoload
@@ -528,17 +530,16 @@ With prefix argument NOCOMMIT, do not create a commit."
 
 (defun sisyphus-tarsius-bump-dependencies (deps version siblings)
   (mapcar (pcase-lambda (`(,pkg ,ver ,align))
-            (let* ((name  (symbol-name pkg))
-                   (ver   (version-to-list ver))
+            (let* ((ver (version-to-list ver))
                    (parts (length ver)))
               (cond-let*
                 ((memq pkg '(emacs compat)))
                 ((memq pkg siblings)
                  (setq ver (version-to-list version)))
-                ([default-directory (borg-worktree name)]
+                ([default-directory (borg-worktree (symbol-name pkg))]
                  [_(file-directory-p default-directory)]
                  (setq ver (version-to-list (sisyphus--previous-version))))
-                ([builtin (alist-get (intern name) package--builtins)]
+                ([builtin (alist-get pkg package--builtins)]
                  (setq ver (aref builtin 0))))
               (list pkg (package-version-join (seq-take ver parts)) align)))
           deps))
